SchemaSpy - Table gnss_data.public.locks

Tables Relationships Utility Tables Constraints Anomalies Columns Donate

Table gnss_data.public.locks | Generated by SchemaSpy

Related columns Constraints Comments Legend |
Legend: |
Primary key columns
Columns with indexes
Implied relationships
Excluded column relationships
< n > number of related tables
Column | Type | Size | Nulls | Auto | Default | Children | Parents | Comments
--- | --- | --- | --- | --- | --- | --- | --- | ---
filename | text | 2147483647 |  |  |  |  |  |
NetworkCode | varchar | 3 | √ |  | null |  |
stations.NetworkCode | locks_NetworkCode_fkey C
StationCode | varchar | 4 | √ |  | null |  |
stations.StationCode | locks_NetworkCode_fkey C
Table contained 63 rows at Fri Jul 28 14:55 EDT 2017

Close relationships within one two degrees of separation: